Method: Net::SFTP::Session#fstat

Defined in:
lib/net/sftp/session.rb

#fstat(handle, flags = nil, &callback) ⇒ Object

The fstat method is identical to the #stat and #lstat methods, with the exception that it takes a handle as the first parameter, such as would be obtained via the #open or #opendir methods. (See the #lstat method for full documentation).



327
328
329
# File 'lib/net/sftp/session.rb', line 327

def fstat(handle, flags=nil, &callback)
  request :fstat, handle, flags, &callback
end