Method: Net::SFTP::Protocol::V01::Base#parse_status_packet

Defined in:
lib/net/sftp/protocol/01/base.rb

#parse_status_packet(packet) ⇒ Object

Parses the given FXP_STATUS packet and returns a hash with one key, :code, which references the status code returned by the server.



36
37
38
# File 'lib/net/sftp/protocol/01/base.rb', line 36

def parse_status_packet(packet)
  { :code => packet.read_long }
end